powered by
Saves critical information in a EGRETci workflow when analyzing trends over a set of two years.
saveEGRETci(eList, eBoot, caseSetUp, fileName = "")
named list with at least the Daily, Sample, and INFO dataframes. Created from the EGRET package, after running modelEstimation.
modelEstimation
named list. Returned from wBT.
wBT
data frame. Returned from trendSetUp.
trendSetUp
character. If left blank (empty quotes), the function will interactively ask for a name to save.
wBT, trendSetUp, modelEstimation
# NOT RUN { library(EGRET) eList <- Choptank_eList # } # NOT RUN { caseSetUp <- trendSetUp(eList) eBoot <- wBT(eList,caseSetUp) saveEGRETci(eList, eBoot, caseSetUp) # }
Run the code above in your browser using DataLab