Learn R Programming

EGRETci (version 1.0.2)

wordLike: Assigns the narrative descriptors to the likelihood of change that is calculated by WBT

Description

Function called in wBT to convert numeric likelihood percentages to useful text.

Usage

wordLike(likeList)

Arguments

likeList

list

Value

character vector for [1] Upward trend in concentration, [2] Downward trend in concentration, [3] Upward trend in flux, [4] Downward trend in flux

Examples

Run this code
# NOT RUN {
likeList <- c(0.01, 0.5, 0.55, 0.99)
Trends <- wordLike(likeList)
# }

Run the code above in your browser using DataLab