Learn R Programming

EGRETci (version 1.0.0)

saveEGRETci: Save EGRETci workspace after wBT

Description

Saves critical information in a EGRETci workflow when analyzing trends over a set of two years.

Usage

saveEGRETci(eList, eBoot, caseSetUp, fileName = "")

Arguments

eList
named list with at least the Daily, Sample, and INFO dataframes. Created from the EGRET package, after running modelEstimation.
eBoot
named list. Returned from wBT.
caseSetUp
data frame. Returned from trendSetUp.
fileName
character. If left blank (empty quotes), the function will interactively ask for a name to save.

See Also

wBT, trendSetUp, modelEstimation

Examples

Run this code
library(EGRET)
eList <- Choptank_eList
caseSetUp <- trendSetUp(eList)
eBoot <- wBT(eList,caseSetUp)
saveEGRETci(eList, eBoot, caseSetUp)

Run the code above in your browser using DataLab